"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.resolveSiteData = exports.resolveConfig = exports.defineConfig = exports.resolveSiteDataByRoute = void 0;
const path_1 = __importDefault(require("path"));
const fs_extra_1 = __importDefault(require("fs-extra"));
const chalk_1 = __importDefault(require("chalk"));
const globby_1 = __importDefault(require("globby"));
const vite_1 = require("vite");
const shared_1 = require("./shared");
const alias_1 = require("./alias");
const debug_1 = __importDefault(require("debug"));
var shared_2 = require("./shared");
Object.defineProperty(exports, "resolveSiteDataByRoute", { enumerable: true, get: function () { return shared_2.resolveSiteDataByRoute; } });
const debug = (0, debug_1.default)('vitepress:config');
const resolve = (root, file) => (0, vite_1.normalizePath)(path_1.default.resolve(root, `.vitepress`, file));
/**
 * Type config helper
 */
function defineConfig(config) {
    return config;
}
exports.defineConfig = defineConfig;
async function resolveConfig(root = process.cwd(), command = 'serve', mode = 'development') {
    const [userConfig, configPath] = await resolveUserConfig(root, command, mode);
    const site = await resolveSiteData(root, userConfig);
    const srcDir = path_1.default.resolve(root, userConfig.srcDir || '.');
    // resolve theme path
    const userThemeDir = resolve(root, 'theme');
    const themeDir = (await fs_extra_1.default.pathExists(userThemeDir))
        ? userThemeDir
        : alias_1.DEFAULT_THEME_PATH;
    // Important: globby/fast-glob doesn't guarantee order of the returned files.
    // We must sort the pages so the input list to rollup is stable across
    // builds - otherwise different input order could result in different exports
    // order in shared chunks which in turns invalidates the hash of every chunk!
    // JavaScript built-in sort() is mandated to be stable as of ES2019 and
    // supported in Node 12+, which is required by Vite.
    const pages = (await (0, globby_1.default)(['**.md'], {
        cwd: srcDir,
        ignore: ['**/node_modules', ...(userConfig.srcExclude || [])]
    })).sort();
    const config = {
        root,
        srcDir,
        site,
        themeDir,
        pages,
        configPath,
        outDir: resolve(root, 'dist'),
        tempDir: path_1.default.resolve(alias_1.APP_PATH, 'temp'),
        markdown: userConfig.markdown,
        alias: (0, alias_1.resolveAliases)(themeDir),
        vue: userConfig.vue,
        vite: userConfig.vite,
        mpa: !!userConfig.mpa
    };
    return config;
}
exports.resolveConfig = resolveConfig;
const supportedConfigExtensions = ['js', 'ts', '.mjs', 'mts'];
async function resolveUserConfig(root, command, mode) {
    var _a;
    // load user config
    let configPath;
    for (const ext of supportedConfigExtensions) {
        const p = resolve(root, `config.${ext}`);
        if (await fs_extra_1.default.pathExists(p)) {
            configPath = p;
            break;
        }
    }
    const userConfig = configPath
        ? (_a = (await (0, vite_1.loadConfigFromFile)({
            command,
            mode
        }, configPath, root))) === null || _a === void 0 ? void 0 : _a.config
        : {};
    if (configPath) {
        debug(`loaded config at ${chalk_1.default.yellow(configPath)}`);
    }
    else {
        debug(`no config file found.`);
    }
    return [await resolveConfigExtends(userConfig), configPath];
}
async function resolveConfigExtends(config) {
    const resolved = await (typeof config === 'function' ? config() : config);
    if (resolved.extends) {
        const base = await resolveConfigExtends(resolved.extends);
        return mergeConfig(base, resolved);
    }
    return resolved;
}
function mergeConfig(a, b, isRoot = true) {
    const merged = { ...a };
    for (const key in b) {
        const value = b[key];
        if (value == null) {
            continue;
        }
        const existing = merged[key];
        if (Array.isArray(existing) && Array.isArray(value)) {
            merged[key] = [...existing, ...value];
            continue;
        }
        if (isObject(existing) && isObject(value)) {
            if (isRoot && key === 'vite') {
                merged[key] = (0, vite_1.mergeConfig)(existing, value);
            }
            else {
                merged[key] = mergeConfig(existing, value, false);
            }
            continue;
        }
        merged[key] = value;
    }
    return merged;
}
function isObject(value) {
    return Object.prototype.toString.call(value) === '[object Object]';
}
async function resolveSiteData(root, userConfig, command = 'serve', mode = 'development') {
    userConfig = userConfig || (await resolveUserConfig(root, command, mode))[0];
    return {
        lang: userConfig.lang || 'en-US',
        title: userConfig.title || 'VitePress',
        description: userConfig.description || 'A VitePress site',
        base: userConfig.base ? userConfig.base.replace(/([^/])$/, '$1/') : '/',
        head: userConfig.head || [],
        themeConfig: userConfig.themeConfig || {},
        locales: userConfig.locales || {},
        langs: (0, shared_1.createLangDictionary)(userConfig)
    };
}
exports.resolveSiteData = resolveSiteData;
//# sourceMappingURL=config.js.map