"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.highlight = void 0;
const chalk_1 = __importDefault(require("chalk"));
const escape_html_1 = __importDefault(require("escape-html"));
const prismjs_1 = __importDefault(require("prismjs"));
// prism is listed as actual dep so it's ok to require
const loadLanguages = require('prismjs/components/index');
// required to make embedded highlighting work...
loadLanguages(['markup', 'css', 'javascript']);
function wrap(code, lang) {
    if (lang === 'text') {
        code = (0, escape_html_1.default)(code);
    }
    return `<pre v-pre><code>${code}</code></pre>`;
}
const highlight = (str, lang) => {
    if (!lang) {
        return wrap(str, 'text');
    }
    lang = lang.toLowerCase();
    const rawLang = lang;
    if (lang === 'vue' || lang === 'html') {
        lang = 'markup';
    }
    if (lang === 'md') {
        lang = 'markdown';
    }
    if (lang === 'ts') {
        lang = 'typescript';
    }
    if (lang === 'py') {
        lang = 'python';
    }
    if (!prismjs_1.default.languages[lang]) {
        try {
            loadLanguages([lang]);
        }
        catch (e) {
            console.warn(chalk_1.default.yellow(`[vitepress] Syntax highlight for language "${lang}" is not supported.`));
        }
    }
    if (prismjs_1.default.languages[lang]) {
        const code = prismjs_1.default.highlight(str, prismjs_1.default.languages[lang], lang);
        return wrap(code, rawLang);
    }
    return wrap(str, 'text');
};
exports.highlight = highlight;
//# sourceMappingURL=highlight.js.map